@@ -1,33 +1,33 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Format;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Object';
 
 use strict;
 use warnings;
 
-use Carp;
 use OODoc::Manifest;
+use Log::Report    'oodoc';
 
 
 sub init($)
 {   my ($self, $args) = @_;
     $self->SUPER::init($args) or return;
 
-    $self->{OF_project} = delete $args->{project}
-        or croak "ERROR: formatter knows no project name.\n";
+    my $name = $self->{OF_project} = delete $args->{project}
+        or error __x"formatter knows no project name";
 
     $self->{OF_version} = delete $args->{version}
-        or croak "ERROR: formatter does not know the version.\n";
+        or error __x"formatter for {name} does not know the version", name => $name;
 
     $self->{OF_workdir} = delete $args->{workdir}
-        or croak "ERROR: no working directory specified.\n";
+        or error __x"no working directory specified for {name}", name => $name;
 
     $self->{OF_manifest} = delete $args->{manifest} || OODoc::Manifest->new;
 
@@ -39,25 +39,15 @@ sub init($)
 
 sub project() {shift->{OF_project}}
 
-#-------------------------------------------
-
 
 sub version() {shift->{OF_version}}
-
-#-------------------------------------------
-
-
 sub workdir() {shift->{OF_workdir}}
-
-#-------------------------------------------
-
-
 sub manifest() {shift->{OF_manifest}}
 
 #-------------------------------------------
 
 
-sub createManual(@) { confess }
+sub createManual(@) {panic}
 
 
 sub cleanup($$)
@@ -68,8 +58,8 @@ sub cleanup($$)
 
 sub showChapter(@)
 {   my ($self, %args) = @_;
-    my $chapter  = $args{chapter} or confess;
-    my $manual   = $args{manual}  or confess;
+    my $chapter  = $args{chapter} or panic;
+    my $manual   = $args{manual}  or panic;
     my $show_ch  = $args{show_inherited_chapter}    || 'REFER';
     my $show_sec = $args{show_inherited_section}    || 'REFER';
     my $show_ssec= $args{show_inherited_subsection} || 'REFER';
@@ -106,10 +96,10 @@ sub showChapter(@)
 #-------------------------------------------
 
 
-sub showStructureExpanded(@) {confess}
+sub showStructureExpanded(@) {panic}
 
 
-sub showStructureRefer(@) {confess}
+sub showStructureRefer(@) {panic}
 
 #-------------------------------------------
 
@@ -130,11 +120,11 @@ sub chapterCopyrights(@)  {shift->showOptionalChapter(COPYRIGHTS  => @_)}
 
 sub showRequiredChapter($@)
 {   my ($self, $name, %args) = @_;
-    my $manual  = $args{manual} or confess;
+    my $manual  = $args{manual} or panic;
     my $chapter = $manual->chapter($name);
 
     unless(defined $chapter)
-    {   warn "WARNING: missing required chapter $name in $manual\n";
+    {   alert "missing required chapter $name in $manual";
         return;
     }
 
@@ -144,7 +134,7 @@ sub showRequiredChapter($@)
 
 sub showOptionalChapter($@)
 {   my ($self, $name, %args) = @_;
-    my $manual  = $args{manual} or confess;
+    my $manual  = $args{manual} or panic;
 
     my $chapter = $manual->chapter($name);
     return unless defined $chapter;
@@ -162,7 +152,7 @@ sub showSubroutines(@)
     my @subs   = $args{subroutines} ? sort @{$args{subroutines}} : [];
     return unless @subs;
 
-    my $manual = $args{manual} or confess;
+    my $manual = $args{manual} or panic;
     my $output = $args{output}    || select;
 
     # list is also in ::Pod3
@@ -196,8 +186,8 @@ sub showSubroutines(@)
 sub showSubroutine(@)
 {   my ($self, %args) = @_;
 
-    my $subroutine = $args{subroutine} or confess;
-    my $manual = $args{manual} or confess;
+    my $subroutine = $args{subroutine} or panic;
+    my $manual = $args{manual} or panic;
     my $output = $args{output} || select;
 
     #
@@ -210,7 +200,7 @@ sub showSubroutine(@)
      : $use eq 'USE'    ? ('showSubroutineUse',  0)
      : $use eq 'NAMES'  ? ('showSubroutineName', 0)
      : $use eq 'NO'     ? (undef,                0)
-     : croak "ERROR: illegal value for show_subroutine: $use";
+     : error __x"illegal value for show_subroutine: {value}", value => $use;
 
     $self->$show_use(%args, subroutine => $subroutine)
        if defined $show_use;
@@ -236,7 +226,7 @@ sub showSubroutine(@)
     elsif($descr eq 'DESCRIBED')
          { $show_descr = undef if $manual->inherited($description) }
     elsif($descr eq 'ALL') {;}
-    else { croak "ERROR: illegal value for show_sub_description: $descr" }
+    else { error __x"illegal value for show_sub_description: {v}", v => $descr}
     
     $self->$show_descr(%args, subroutine => $description)
           if defined $show_descr;
@@ -257,7 +247,7 @@ sub showSubroutine(@)
      : $opttab eq 'DESCRIBED'? (grep {not $manual->inherits($_->[0])} @options)
      : $opttab eq 'INHERITED'? (grep {$manual->inherits($_->[0])} @options)
      : $opttab eq 'ALL'      ? @options
-     : croak "ERROR: illegal value for show_option_table: $opttab";
+     : error __x"illegal value for show_option_table: {v}", v => $opttab;
     
     $self->showOptionTable(%args, options => \@opttab)
        if @opttab;
@@ -306,9 +296,9 @@ sub showSubroutineDescription(@) {shift}
 
 sub showOptionTable(@)
 {   my ($self, %args) = @_;
-    my $options = $args{options} or confess;
-    my $manual  = $args{manual}  or confess;
-    my $output  = $args{output}  or confess;
+    my $options = $args{options} or panic;
+    my $manual  = $args{manual}  or panic;
+    my $output  = $args{output}  or panic;
 
     my @rows;
     foreach (@$options)
@@ -344,8 +334,8 @@ sub showOptionTable(@)
 sub showOptions(@)
 {   my ($self, %args) = @_;
 
-    my $options = $args{options} or confess;
-    my $manual  = $args{manual}  or confess;
+    my $options = $args{options} or panic;
+    my $manual  = $args{manual}  or panic;
 
     foreach (@$options)
     {   my ($option, $default) = @$_;
@@ -356,7 +346,7 @@ sub showOptions(@)
         my $action
           = $show eq 'USE'   ? 'showOptionUse'
           : $show eq 'EXPAND'? 'showOptionExpand'
-          : croak "ERROR: illegal show option choice $show";
+          : error __x"illegal show option choice: {v}", v => $show;
  
         $self->$action(%args, option => $option, default => $default);
     }
