@@ -1,46 +1,48 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 package OODoc::Format::Pod;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Format';
 
 use strict;
 use warnings;
 
+use Log::Report    'oodoc';
+
 use File::Spec   ();
-use Carp         qw/confess/;
 use List::Util   qw/max/;
 use Pod::Escapes qw/e2char/;
 
 
 sub link($$;$)
 {   my ($self, $manual, $object, $text) = @_;
+
     $object = $object->subroutine if $object->isa('OODoc::Text::Option');
     $object = $object->subroutine if $object->isa('OODoc::Text::Default');
     $object = $object->container  if $object->isa('OODoc::Text::Example');
     $object = $object->container  if $object->isa('OODoc::Text::Subroutine');
     $text   = defined $text ? "$text|" : '';
 
-    return "L<$text$object>" if $object->isa('OODoc::Manual');
+    return "L<$text$object>"
+        if $object->isa('OODoc::Manual');
+
+    $object->isa('OODoc::Text::Structure')
+        or error __x"cannot link to a {pkg}", pkg => ref $object;
 
     my $manlink = defined $manual ? $object->manual.'/' : '';
-
-      $object->isa('OODoc::Text::Structure') ? qq(L<$text$manlink"$object">)
-    : confess "cannot link to a ".ref $object;
+    qq(L<$text$manlink"$object">);
 }
 
 
 sub createManual($@)
 {   my ($self, %args) = @_;
-    my $verbose  = $args{verbose} || 0;
-    my $manual   = $args{manual} or confess;
+    my $manual   = $args{manual} or panic;
     my $options  = $args{format_options} || [];
 
-    print $manual->orderedChapters." chapters in $manual\n" if $verbose>=3;
     my $podname  = $manual->source;
     $podname     =~ s/\.pm$/.pod/;
     my $tmpname  =  $podname . 't';
@@ -49,7 +51,8 @@ sub createManual($@)
     my $podfile  = File::Spec->catfile($self->workdir, $podname);
 
     my $output  = IO::File->new($tmpfile, "w")
-        or die "ERROR: cannot write prelimary pod manual to $tmpfile: $!";
+        or fault __x"cannot write prelimary pod manual to {file}"
+            , file => $tmpfile;
 
     $self->formatManual
       ( manual => $manual
@@ -93,7 +96,7 @@ sub showAppend(@)
        if(!defined $append)      { ; }
     elsif(ref $append eq 'CODE') { $append->(formatter => $self, %args) }
     else
-    {   my $output = $args{output} or confess;
+    {   my $output = $args{output} or panic;
         $output->print($append);
     }
 
@@ -104,12 +107,12 @@ sub showStructureExpand(@)
 {   my ($self, %args) = @_;
 
     my $examples = $args{show_chapter_examples} || 'EXPAND';
-    my $text     = $args{structure} or confess;
+    my $text     = $args{structure} or panic;
 
     my $name     = $text->name;
     my $level    = $text->level;
-    my $output   = $args{output}  or confess;
-    my $manual   = $args{manual}  or confess;
+    my $output   = $args{output}  or panic;
+    my $manual   = $args{manual}  or panic;
 
     my $descr   = $self->cleanup($manual, $text->description);
     $output->print("\n=head$level $name\n\n$descr");
@@ -124,12 +127,12 @@ sub showStructureExpand(@)
 sub showStructureRefer(@)
 {   my ($self, %args) = @_;
 
-    my $text     = $args{structure} or confess;
+    my $text     = $args{structure} or panic;
 
     my $name     = $text->name;
     my $level    = $text->level;
-    my $output   = $args{output}  or confess;
-    my $manual   = $args{manual}  or confess;
+    my $output   = $args{output}  or panic;
+    my $manual   = $args{manual}  or panic;
 
     my $link     = $self->link($manual, $text);
     $output->print("\n=head$level $name\n\nSee $link.\n");
@@ -141,19 +144,19 @@ sub chapterDescription(@)
 
     $self->showRequiredChapter(DESCRIPTION => %args);
 
-    my $manual  = $args{manual} or confess;
+    my $manual  = $args{manual} or panic;
     my $details = $manual->chapter('DETAILS');
    
     return $self unless defined $details;
 
-    my $output  = $args{output} or confess;
+    my $output  = $args{output} or panic;
     $output->print("\nSee L</DETAILS> chapter below\n");
     $self->showChapterIndex($output, $details, "   ");
 }
 
 sub chapterDiagnostics(@)
 {   my ($self, %args) = @_;
-    my $manual  = $args{manual} or confess;
+    my $manual  = $args{manual} or panic;
 
     my $diags   = $manual->chapter('DIAGNOSTICS');
     $self->showChapter(chapter => $diags, %args)
@@ -162,7 +165,7 @@ sub chapterDiagnostics(@)
     my @diags   = map {$_->diagnostics} $manual->subroutines;
     return unless @diags;
 
-    my $output  = $args{output} or confess;
+    my $output  = $args{output} or panic;
     $diags
         or $output->print("\n=head1 DIAGNOSTICS\n");
 
@@ -188,11 +191,11 @@ sub showChapterIndex($$;$)
 
 sub showExamples(@)
 {   my ($self, %args) = @_;
-    my $examples = $args{examples} or confess;
+    my $examples = $args{examples} or panic;
     return unless @$examples;
 
-    my $manual    = $args{manual}  or confess;
-    my $output    = $args{output}  or confess;
+    my $manual    = $args{manual}  or panic;
+    my $output    = $args{output}  or panic;
 
     foreach my $example (@$examples)
     {   my $name    = $self->cleanup($manual, $example->name);
@@ -205,11 +208,11 @@ sub showExamples(@)
 
 sub showDiagnostics(@)
 {   my ($self, %args) = @_;
-    my $diagnostics = $args{diagnostics} or confess;
+    my $diagnostics = $args{diagnostics} or panic;
     return unless @$diagnostics;
 
-    my $manual    = $args{manual}  or confess;
-    my $output    = $args{output}  or confess;
+    my $manual    = $args{manual}  or panic;
+    my $output    = $args{output}  or panic;
 
     foreach my $diag (sort @$diagnostics)
     {   my $name    = $self->cleanup($manual, $diag->name);
@@ -226,7 +229,7 @@ sub showSubroutines(@)
     my $subs = $args{subroutines} || [];
     @$subs or return;
 
-    my $output = $args{output} or confess;
+    my $output = $args{output} or panic;
 
     $output->print("\n=over 4\n\n");
     $self->SUPER::showSubroutines(%args);
@@ -238,21 +241,21 @@ sub showSubroutine(@)
     $self->SUPER::showSubroutine(@_);
 
     my %args   = @_;
-    my $output = $args{output} or confess;
+    my $output = $args{output} or panic;
     $output->print("\n");
     $self;
 }
 
 sub showSubroutineUse(@)
 {   my ($self, %args) = @_;
-    my $subroutine = $args{subroutine} or confess;
-    my $manual     = $args{manual}     or confess;
-    my $output     = $args{output}     or confess;
+    my $subroutine = $args{subroutine} or panic;
+    my $manual     = $args{manual}     or panic;
+    my $output     = $args{output}     or panic;
 
-    my $use        = $self->subroutineUse($manual, $subroutine);
-
-    $output->print("=item $use\n\n");
+    my $use = $self->subroutineUse($manual, $subroutine);
+    $use    =~ s/(.+)/=item $1\n\n/gm;
 
+    $output->print($use);
     $output->print("See ". $self->link($manual, $subroutine)."\n\n")
         if $manual->inherited($subroutine);
 
@@ -264,13 +267,13 @@ sub subroutineUse($$)
     my $type       = $subroutine->type;
     my $name       = $self->cleanup($manual, $subroutine->name);
     my $paramlist  = $self->cleanup($manual, $subroutine->parameters);
-    my $params     = length $paramlist ? "($paramlist)" : '';
+    my $params     = length $paramlist ? "($paramlist)" : '()';
 
     my $class      = $manual->package;
     my $use
      = $type eq 'i_method' ? qq[\$obj-E<gt>B<$name>$params]
      : $type eq 'c_method' ? qq[$class-E<gt>B<$name>$params]
-     : $type eq 'ci_method'? qq[\$obj-E<gt>B<$name>$params\n\n]
+     : $type eq 'ci_method'? qq[\$obj-E<gt>B<$name>$params\n]
                            . qq[$class-E<gt>B<$name>$params]
      : $type eq 'function' ? qq[B<$name>$params]
      : $type eq 'overload' ? qq[overload: B<$name>$params]
@@ -285,9 +288,9 @@ sub subroutineUse($$)
 
 sub showSubroutineName(@)
 {   my ($self, %args) = @_;
-    my $subroutine = $args{subroutine} or confess;
-    my $manual     = $args{manual}     or confess;
-    my $output     = $args{output}     or confess;
+    my $subroutine = $args{subroutine} or panic;
+    my $manual     = $args{manual}     or panic;
+    my $output     = $args{output}     or panic;
     my $name       = $subroutine->name;
 
     my $url
@@ -303,7 +306,7 @@ sub showSubroutineName(@)
 
 sub showOptions(@)
 {   my ($self, %args) = @_;
-    my $output = $args{output} or confess;
+    my $output = $args{output} or panic;
     $output->print("\n=over 2\n\n");
     $self->SUPER::showOptions(%args);
     $output->print("\n=back\n\n");
@@ -311,9 +314,9 @@ sub showOptions(@)
 
 sub showOptionUse(@)
 {   my ($self, %args) = @_;
-    my $output = $args{output} or confess;
-    my $option = $args{option} or confess;
-    my $manual = $args{manual}  or confess;
+    my $output = $args{output} or panic;
+    my $option = $args{option} or panic;
+    my $manual = $args{manual}  or panic;
 
     my $params = $option->parameters;
     $params    =~ s/\s+$//;
@@ -326,9 +329,9 @@ sub showOptionUse(@)
 
 sub showOptionExpand(@)
 {   my ($self, %args) = @_;
-    my $output = $args{output} or confess;
-    my $option = $args{option} or confess;
-    my $manual = $args{manual}  or confess;
+    my $output = $args{output} or panic;
+    my $option = $args{option} or panic;
+    my $manual = $args{manual}  or panic;
 
     $self->showOptionUse(%args);
 
@@ -344,9 +347,9 @@ sub showOptionExpand(@)
 sub writeTable($@)
 {   my ($self, %args) = @_;
 
-    my $head   = $args{header} or confess;
-    my $output = $args{output} or confess;
-    my $rows   = $args{rows}   or confess;
+    my $head   = $args{header} or panic;
+    my $output = $args{output} or panic;
+    my $rows   = $args{rows}   or panic;
     return unless @$rows;
 
     # Convert all elements to plain text, because markup is not
@@ -365,8 +368,8 @@ sub writeTable($@)
     }
 
     if(my $widths = $args{widths})
-    {   defined $widths->[$_] && ($w[$_] = $widths->[$_])
-           foreach 0..$#$rows;
+    {   defined $widths->[$_] && $widths->[$_] > $w[$_] && ($w[$_] = $widths->[$_])
+           for 0..$#$rows;
     }
 
     pop @w;   # ignore width of last column
@@ -452,13 +455,13 @@ sub _removeMarkup($)
 
 sub showSubroutineDescription(@)
 {   my ($self, %args) = @_;
-    my $manual  = $args{manual}                   or confess;
-    my $subroutine = $args{subroutine}            or confess;
+    my $manual  = $args{manual}                   or panic;
+    my $subroutine = $args{subroutine}            or panic;
 
     my $text    = $self->cleanup($manual, $subroutine->description);
     return $self unless length $text;
 
-    my $output  = $args{output}                   or confess;
+    my $output  = $args{output}                   or panic;
     $output->print("\n", $text);
 
     my $extends = $self->extends                  or return $self;
@@ -468,9 +471,9 @@ sub showSubroutineDescription(@)
 
 sub showSubroutineDescriptionRefer(@)
 {   my ($self, %args) = @_;
-    my $manual  = $args{manual}                   or confess;
-    my $subroutine = $args{subroutine}            or confess;
-    my $output  = $args{output}                   or confess;
+    my $manual  = $args{manual}                   or panic;
+    my $subroutine = $args{subroutine}            or panic;
+    my $output  = $args{output}                   or panic;
     $output->print("\nSee ", $self->link($manual, $subroutine), "\n");
 }
 
@@ -480,10 +483,10 @@ sub showSubsIndex() {;}
 sub cleanupPOD($$)
 {   my ($self, $infn, $outfn) = @_;
     my $in = IO::File->new($infn, 'r')
-        or die "ERROR: cannot read prelimary pod from $infn: $!\n";
+        or fault __x"cannot read prelimary pod from {file}", file => $infn;
 
     my $out = IO::File->new($outfn, 'w')
-        or die "ERROR: cannot write final pod to $outfn: $!\n";
+        or fault __x"cannot write final pod to {file}", file => $outfn;
 
     my $last_is_blank = 1;
   LINE:
@@ -501,7 +504,7 @@ sub cleanupPOD($$)
 
     $in->close;
     $out->close
-       or die "ERROR: write to $outfn failed: $!\n";
+        or fault __x"write to {file} failed", file => $outfn;
 
     $self;
 }
