@@ -1,23 +1,23 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Format::Pod2;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base qw/OODoc::Format::Pod OODoc::Format::TemplateMagic/;
 
 use strict;
 use warnings;
 
-use Carp;
+use Log::Report    'oodoc';
+use Template::Magic;
+
 use File::Spec;
 use IO::Scalar;
 
-use Template::Magic;
-
 
 my $default_template;
 {   local $/;
@@ -55,20 +55,23 @@ sub formatManual(@)
 sub templateChapter($$)
 {   my ($self, $zone, $args) = @_;
     my $contained = $zone->content;
-    warn "WARNING: no meaning for container $contained in chapter block\n"
-        if defined $contained && length $contained;
+    defined $contained && length $contained
+        or warning __x"no meaning for container {c} in chapter block"
+             , c => $contained;
 
     my $attrs = $zone->attributes;
     my $name  = $attrs =~ s/^\s*(\w+)\s*\,?// ? $1 : undef;
 
-    croak "ERROR: chapter without name in template.", return ''
-       unless defined $name;
+    unless(defined $name)
+    {   error __x"chapter without name in template.";
+        return '';
+    }
 
     my @attrs = $self->zoneGetParameters($attrs);
     my $out   = '';
 
-    $self->showOptionalChapter($name, %$args,
-       output => IO::Scalar->new(\$out), @attrs);
+    $self->showOptionalChapter($name, %$args
+      , output => IO::Scalar->new(\$out), @attrs);
 
     $out;
 }
@@ -98,6 +101,7 @@ __DATA__
 {chapter OVERLOADED}
 {chapter METHODS}
 {chapter FUNCTIONS}
+{chapter CONSTANTS}
 {chapter EXPORTS}
 {chapter DETAILS}
 {diagnostics}
