@@ -1,16 +1,17 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package OODoc::Format::Pod3;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Format::Pod';
 
+use Log::Report    'oodoc';
 use OODoc::Template;
 
 
@@ -35,7 +36,8 @@ sub formatManual(@)
      , manual_obj => delete $args{manual}
      , chapter_order =>
          [ qw/NAME INHERITANCE SYNOPSIS DESCRIPTION OVERLOADED METHODS
-              FUNCTIONS EXPORTS DIAGNOSTICS DETAILS REFERENCES COPYRIGHTS/
+              FUNCTIONS CONSTANTS EXPORTS DIAGNOSTICS DETAILS REFERENCES
+              COPYRIGHTS/
          ]
      , %args
      );
@@ -183,8 +185,8 @@ sub diagnostics($$$$$$)
 __DATA__
 <{macro name=structure}>\
    <{description}>\
-   <{subroutines}>\
    <{template macro=examples}>\
+   <{subroutines}>\
 <{/macro}>\
 
 
@@ -206,16 +208,19 @@ __DATA__
 =head1 <{chapter}>
 
 \
+    <{template macro=structure}>\
     <{sections}>\
 
 =head2 <{section}>
 
 \
+      <{template macro=structure}>\
       <{subsections}>\
 
 =head3 <{subsection}>
 
 \
+        <{template macro=structure}>\
         <{subsubsections}>\
 
 =head4 <{subsubsection}>
@@ -224,13 +229,10 @@ __DATA__
           <{template macro=structure}>\
         <{/subsubsections}>\
 
-        <{template macro=structure}>\
       <{/subsections}>\
 
-      <{template macro=structure}>\
     <{/sections}>\
 
-    <{template macro=structure}>\
   <{/chapters}>\
 
   <{diagnostics}>\
