@@ -1,20 +1,20 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Manifest;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Object';
 
 use strict;
 use warnings;
 
-use Carp;
 use IO::File;
 use File::Basename 'dirname';
+use Log::Report    'oodoc';
 
 
 use overload '@{}' => sub { [ shift->files ] };
@@ -65,7 +65,7 @@ sub read()
 {   my $self = shift;
     my $filename = $self->filename;
     my $file = IO::File->new($filename, "r")
-       or die "ERROR: Cannot read manifest file $filename: $!\n";
+       or fault __x"cannot read manifest file {file}", file => $filename;
 
     my @dist = $file->getlines;
     $file->close;
@@ -92,7 +92,7 @@ sub write()
     my $filename = $self->filename || return $self;
 
     my $file = IO::File->new($filename, "w")
-      or die "ERROR: Cannot write manifest $filename: $!\n";
+      or fault __x"cannot write manifest {file}", file => $filename;
 
     $file->print($_, "\n") foreach sort $self->files;
     $file->close;
