@@ -1,19 +1,19 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Parser;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Object';
 
 use strict;
 use warnings;
 
-use Carp;
-use List::Util qw/first/;
+use Log::Report    'oodoc';
+use List::Util     'first';
 
 
 #-------------------------------------------
@@ -25,7 +25,7 @@ sub init($)
 
     my $skip = delete $args->{skip_links} || [];
     my @skip = map { ref $_ eq 'Regexp' ? $_ : qr/^\Q$_\E(?:\:\:|$)/ }
-       ref $skip eq 'ARRAY' ? @$skip : $skip;
+        ref $skip eq 'ARRAY' ? @$skip : $skip;
     $self->{skip_links} = \@skip;
 
     $self;
@@ -34,7 +34,7 @@ sub init($)
 #-------------------------------------------
 
 
-sub parse(@) { confess }
+sub parse(@) {panic}
 
 #-------------------------------------------
 
@@ -52,10 +52,11 @@ sub cleanup($$$)
        if $formatter->isa('OODoc::Format::Pod');
 
     return $self->cleanupHtml($formatter, $manual, $string)
-       if $formatter->isa('OODoc::Format::Html');
+       if $formatter->isa('OODoc::Format::Html')
+       || $formatter->isa('OODoc::Format::Html2');
 
-    croak "ERROR: The formatter type ".ref($formatter)
-        . " is not known for cleanup\n";
+    error __x"the formatter type {type} is not known for cleanup"
+      , type => ref $formatter;
 
     $string;
 }
