@@ -1,17 +1,19 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Parser::Markov;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Parser';
 
 use strict;
 use warnings;
 
+use Log::Report    'oodoc';
+
 use OODoc::Text::Chapter;
 use OODoc::Text::Section;
 use OODoc::Text::SubSection;
@@ -23,7 +25,6 @@ use OODoc::Text::Diagnostic;
 use OODoc::Text::Example;
 use OODoc::Manual;
 
-use Carp;
 use File::Spec;
 use IO::File;
 
@@ -80,7 +81,7 @@ sub init($)
         if exists $args->{additional_rules};
 
     $self->{OP_rules} = [];
-    $self->rule(@$_) foreach @rules;
+    $self->rule(@$_) for @rules;
     $self;
 }
 
@@ -117,11 +118,11 @@ sub parse(@)
 {   my ($self, %args) = @_;
 
     my $input   = $args{input}
-       or croak "ERROR: no input file to parse specified";
+       or error __x"no input file to parse specified";
 
     my $output  = $args{output} || File::Spec->devnull;
-    my $version = $args{version}      or confess;
-    my $distr   = $args{distribution} or confess;
+    my $version = $args{version}      or panic;
+    my $distr   = $args{distribution} or panic;
 
     my $in     = IO::File->new($input, 'r')
        or die "ERROR: cannot read document from $input: $!\n";
@@ -178,8 +179,22 @@ sub parse(@)
             push @manuals, $manual;
             $self->currentManual($manual);
         }
+        elsif(!$self->inDoc && $line =~ m/^=package\s*([\w\-\:]+)\s*$/)
+        {   my $package = $1;
+            $manual = OODoc::Manual->new
+             ( package  => $package
+             , source   => $input
+             , stripped => $output
+             , parser   => $self
+             , distribution => $distr
+             , version      => $version
+             );
+            push @manuals, $manual;
+            $self->currentManual($manual);
+        }
         elsif(my($match, $action) = $self->findMatchingRule($line))
         {
+
             if(ref $action)
             {   $action->($self, $match, $line, $input, $ln)
                   or $out->print($line);
@@ -829,7 +844,6 @@ sub cleanupHtml($$$;$)
         }
         s/\bM\<([^>]*)\>/$self->cleanupHtmlM($formatter, $manual, $1)/ge;
         s/\bL\<([^>]*)\>/$self->cleanupHtmlL($formatter, $manual, $1)/ge;
-        s#\bF\<([^>]*)\>#<a href="$url_coderoot"/$1>$1</a>#g;
         s#\bC\<([^>]*)\>#<code>$1</code>#g;
         s#\bI\<([^>]*)\>#<em>$1</em>#g;
         s#\bB\<([^>]*)\>#<b>$1</b>#g;
@@ -839,6 +853,11 @@ sub cleanupHtml($$$;$)
         s#(?:\A|\s*)\=back\b#\n</ul>#gms;
         s#^=pod\b##gm;
  
+        # when F<> contains a URL, it will be used. However, when it
+        # contains a file, we cannot do anything with it yet.
+        s#\bF\<(\w+\://[^>]*)\>#<a href="$1">$1</a>#g;
+        s#\bF\<([^>]*)\>#<tt>$1</tt>#g;
+
         my ($label, $level, $title);
         s#^\=head([1-6])\s*([^\n]*)#
           ($title, $level) = ($1, $2);
