@@ -1,28 +1,29 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Text::Chapter;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Text::Structure';
 
 use strict;
 use warnings;
 
-use List::Util 'first';
-use Carp;
+use Log::Report    'oodoc';
+use List::Util     'first';
 
 
 sub init($)
 {   my ($self, $args) = @_;
     $args->{type}       ||= 'Chapter';
-    $args->{container}  ||= delete $args->{manual} or confess;
+    $args->{container}  ||= delete $args->{manual} or panic;
     $args->{level}      ||= 1;
 
-    $self->SUPER::init($args) or return;
+    $self->SUPER::init($args)
+        or return;
 
     $self->{OTC_sections} = [];
 
