@@ -1,28 +1,29 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Text::Option;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Text';
 
 use strict;
 use warnings;
 
-use Carp;
+use Log::Report    'oodoc';
 
 
 sub init($)
 {   my ($self, $args) = @_;
     $args->{type}    ||= 'Option';
-    $args->{container} = delete $args->{subroutine} or confess;
+    $args->{container} = delete $args->{subroutine} or panic;
 
-    $self->SUPER::init($args) or return;
+    $self->SUPER::init($args)
+        or return;
 
-    $self->{OTO_parameters} = delete $args->{parameters} or confess;
+    $self->{OTO_parameters} = delete $args->{parameters} or panic;
 
     $self;
 }
@@ -32,11 +33,7 @@ sub init($)
 
 sub subroutine() { shift->container }
 
-#-------------------------------------------
-
 
 sub parameters() { shift->{OTO_parameters} }
 
-#-------------------------------------------
-
 1;
