@@ -1,27 +1,28 @@
-# Copyrights 2003-2011 by Mark Overmeer.
+# Copyrights 2003-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 package OODoc::Text::SubSubSection;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '2.00';
 
 use base 'OODoc::Text::Structure';
 
 use strict;
 use warnings;
 
-use Carp;
+use Log::Report    'oodoc';
 
 
 sub init($)
 {   my ($self, $args) = @_;
     $args->{type}      ||= 'Subsubsection';
-    $args->{container} ||= delete $args->{subsection} or confess;
+    $args->{container} ||= delete $args->{subsection} or panic;
     $args->{level}     ||= 3;
 
-    $self->SUPER::init($args) or return;
+    $self->SUPER::init($args)
+        or return;
 
     $self;
 }
@@ -31,6 +32,7 @@ sub findEntry($)
    $self->name eq $name ? $self : ();
 }
 
+#--------------
 
 sub subsection() { shift->container }
 
